﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Resources;
using System.Windows;
using Dapfor.Wpf.Controls;
using Dapfor.Wpf.Grid.Demo.Internal;

namespace Dapfor.Wpf.Grid.Demo.Examples.Basics.Themes
{
    /// <summary>
    ///     Interaction logic for ThemesDemo.xaml
    /// </summary>
    [Example("Basics", "Themes", "Description_ThemesDemo")]
    public partial class ThemesDemo
    {
        private readonly List<Theme> _collection = new List<Theme>();

        public ThemesDemo()
        {
            InitializeComponent();

            using (var stream = typeof (GridControl).Assembly.GetManifestResourceStream(typeof (GridControl).Assembly.GetName().Name + ".g.resources"))
            using (var reader = stream != null ? new ResourceReader(stream) : null)
            {
                if (reader != null)
                {
                    foreach (DictionaryEntry v in reader)
                    {
                        var s = v.Key.ToString();
                        if (s.StartsWith("themes/"))
                        {
                            s = s.Replace("themes/", "");
                            s = s.Replace(".baml", "");

                            if (string.Compare("BasicTheme", s, StringComparison.InvariantCultureIgnoreCase) != 0 &&
                                string.Compare("Generic", s, StringComparison.InvariantCultureIgnoreCase) != 0)
                            {
                                s += ".xaml";
                                if (s[0] >= 'a' && s[0] <= 'z')
                                {
                                    var ch = (char) (s[0] + ('A' - 'a'));
                                    s = ch + s.Substring(1, s.Length - 1);
                                }

                                _collection.Add(new Theme(s));
                            }
                        }
                    }
                }
            }

            _collection.Sort((x, y) => string.Compare(x.Name, y.Name, StringComparison.Ordinal));
            _collection.Insert(0, new Theme(Properties.Resources.NoTheme));

            gridThemes.ItemsSource = _collection;
            gridThemes.Resources.MergedDictionaries.Add(new ResourceDictionary {Source = new Uri("/Dapfor.Wpf;component/Themes/Theme1.xaml", UriKind.RelativeOrAbsolute)});

            grid.Headers[1]["IdIndex"].SortDirection = SortDirection.Ascending;
            grid.Headers[1]["IdPeriod"].SortDirection = SortDirection.Descending;
            PopulateDataObjects();

            gridThemes.Rows[0].Selected = true;
            gridThemes.Rows[0].Focused = true;
        }

        private void PopulateDataObjects()
        {
            var random = new Random();

            //Populate with some data
            for (var i = 0; i < 8; ++i)
            {
                //Populate with top-level items
                var rootObject = new RootClass(i,
                    random.NextDouble(),
                    random.Next(1000, 20000),
                    random.Next()%2 == 0 ? RootClass.EnumExample.Internal : RootClass.EnumExample.External);
                //Add to the grid
                var rootRow = grid.Rows.Add(rootObject);

                rootRow.Expanded = i == 0 || i == 5;

                //Add ten children to each root
                for (var j = 0; j < 4; ++j)
                {
                    var childObject = new ChildClass(i,
                        j,
                        DateTime.Now + new TimeSpan(1000000000000*(random.Next()%1000)),
                        random.Next(5),
                        new TimeSpan(random.Next()));
                    //Add as a child
                    rootRow.Add(childObject);
                }
            }

            for (int i = 3; i < 9; ++i)
            {
                grid.Rows[i].Selected = true;
            }
            grid.Rows[9].Focused = true;
        }

        private void OnThemesRowSelectionChanged(object sender, GridControlRowEventArgs e)
        {
            string themeName = null;
            var row = gridThemes.Selection.Count > 0 ? gridThemes.Selection[0] : null;
            if (row != null)
            {
                themeName = ((Theme) row.DataObject).Name;
                if (string.Equals(themeName, Properties.Resources.NoTheme))
                {
                    themeName = null;
                }
            }

            grid.Resources.MergedDictionaries.Clear();
            if (!string.IsNullOrEmpty(themeName))
            {
                var dico = new ResourceDictionary();
                dico.Source = new Uri("/Dapfor.Wpf;component/Themes/" + themeName, UriKind.RelativeOrAbsolute);
                grid.Resources.MergedDictionaries.Add(dico);
            }
        }

        private class Theme
        {
            public Theme(string name)
            {
                Name = name;
            }

            public string Name { get; private set; }
        }
    }
}