﻿using System;
using System.Collections.Generic;
using System.Text.RegularExpressions;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using Dapfor.Wpf.Controls;
using Dapfor.Wpf.Grid.Demo.Internal;
using Dapfor.Wpf.Grid.Demo.Utils;
using Dapfor.Wpf.Utils;

namespace Dapfor.Wpf.Grid.Demo.Examples.DataBinding.BindingToMultipleSources
{
    /// <summary>
    /// Interaction logic for BindingToMultipleSourcesDemo.xaml
    /// </summary>
    [Example("Data binding", "Binding to multiple sources", "Description_BindingToMultipleSourcesDemo")]
    public partial class BindingToMultipleSourcesDemo : IDisposable
    {
        private readonly Collections _collections;
        private readonly Random _r = new Random();
        private string _filterExpression = string.Empty;

        public BindingToMultipleSourcesDemo()
        {
            InitializeComponent();

            _collections = (Collections) FindResource("collections");
            
            //Create some orders and strategies
            AddNewOrder();
            AddNewStrategy();
            AddNewOrder();
            AddNewStrategy();
            AddNewStrategy();
            AddNewOrder();
            AddNewOrder();
            AddNewStrategy();

            //Select some rows and strategies
            gridOrders.Rows[2].Selected = true;
            gridOrders.Rows[3].Selected = true;
            gridStrategies.Rows[1].Selected = true;

            grid.Rows[3].Selected = true;
            grid.Rows[5].Selected = true;
            grid.Rows[6].Selected = true;


            grid.Filter = new Filter(IsRowFiltered);
        }

        #region IDisposable Members

        public void Dispose()
        {
            _collections.Orders.Clear();
            _collections.Strategies.Clear();

            BindingOperations.ClearAllBindings(this);
        }

        #endregion

        private void AddNewStrategy()
        {
            var strategy = new Strategy("Strategy #" + (_collections.Strategies.Count + 1),
                                        _r.Next(1000, 5000) + _r.NextDouble(),
                                        _r.Next(1, 100));

            _collections.Strategies.Add(strategy);
        }

        private void AddNewOrder()
        {
            var order = new Order("Order #" + (_collections.Orders.Count + 1),
                                  "Instrument #" + _r.Next(100, 10000),
                                  _r.Next(100, 500) + _r.NextDouble(),
                                  _r.Next(100, 10000));

            _collections.Orders.Add(order);
        }

        private bool IsRowFiltered(Row row)
        {
            Cell cell = row["IdName"];
            string text = cell != null ? cell.Text : string.Empty;
            if (!string.IsNullOrEmpty(_filterExpression) && cell != null && !string.IsNullOrEmpty(text))
            {
                try
                {
                    return !(Regex.IsMatch(cell.Text, "^" + _filterExpression, RegexOptions.Singleline | RegexOptions.IgnoreCase));
                }
                catch
                {
                    return false;
                }
            }
            return false;
        }

        #region Private event handlers

        private void btnOrder_Add(object sender, RoutedEventArgs e)
        {
            AddNewOrder();
        }

        private void btnOrders_Remove(object sender, RoutedEventArgs e)
        {
            //Copy selected rows
            var selection = new List<Row>(gridOrders.Selection);
            foreach (Row row in selection)
            {
                _collections.Orders.Remove((Order) row.DataObject);
            }
            btnRemoveOrders.IsEnabled = false;
        }

        private void btnStrategy_Add(object sender, RoutedEventArgs e)
        {
            AddNewStrategy();
        }

        private void btnStrategies_Remove(object sender, RoutedEventArgs e)
        {
            //Copy selected rows
            var selection = new List<Row>(gridStrategies.Selection);
            foreach (Row row in selection)
            {
                _collections.Strategies.Remove((Strategy) row.DataObject);
            }
            btnRemoveStrategies.IsEnabled = false;
        }

        private void gridOrders_SelectionChanged(object sender, GridControlRowEventArgs e)
        {
            btnRemoveOrders.IsEnabled = gridOrders.Selection.Count > 0;
        }

        private void gridStrategies_SelectionChanged(object sender, GridControlRowEventArgs e)
        {
            btnRemoveStrategies.IsEnabled = gridStrategies.Selection.Count > 0;
        }

        private void tbFilter_TextChanged(object sender, TextChangedEventArgs e)
        {
            _filterExpression = tbFilter.Text;
            if (!_filterExpression.Contains("*"))
            {
                _filterExpression = "*" + _filterExpression + "*";
            }
            _filterExpression = _filterExpression.Replace("*", ".*");
            _filterExpression = _filterExpression.Replace("?", ".");


            grid.FilterRefresh();
        }

        #endregion

    }
}