﻿using System;
using System.ComponentModel;
using Dapfor.Wpf.Converters;
using Dapfor.Wpf.Data;

namespace Dapfor.Wpf.Grid.Demo.Examples.DataBinding.ConditionalHierarchicalBinding
{
    public class Basket : INotifyPropertyChanged
    {
        #region Fields

        #endregion

        public Basket(string id)
        {
            Orders = new BindingList<Order>();
            Id = id;
            CreationDate = LastChangeTimeStamp = DateTime.Now;
        }

        #region Public properties

        public BindingList<Order> Orders { get; private set; }

        [Field("TimeStamp")]
        [Converter("HH:mm:ss.fff")]
        public DateTime CreationDate { get; private set; }

        [Converter("HH:mm:ss.fff")]
        public DateTime LastChangeTimeStamp { get; private set; }

        public string Id { get; private set; }

        public Status Status
        {
            get
            {
                Status status = Status.Created;
                foreach (Order order in Orders)
                {
                    switch (order.Status)
                    {
                        case Status.Cancelled:
                            if (!Equals(status, Status.Active))
                            {
                                status = Status.Cancelled;
                            }
                            break;

                        case Status.Active:
                            status = Status.Active;
                            break;
                    }
                }
                return status;
            }
        }

        #endregion

        #region Public methods

        public void AddOrder(Order order)
        {
            if (order == null)
            {
                throw new ArgumentNullException("order");
            }

            Orders.Add(order);
            order.PropertyChanged += OnOrderStatusChanged;
        }

        #endregion

        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        #endregion

        #region Private methods

        private void OnOrderStatusChanged(object sender, PropertyChangedEventArgs e)
        {
            UpdateChangeTimeStamp();
            switch (e.PropertyName)
            {
                case "Status":
                    FirePropertyChanged("Status");
                    break;
            }
        }

        private void UpdateChangeTimeStamp()
        {
            LastChangeTimeStamp = DateTime.Now;
            FirePropertyChanged("LastChangeTimeStamp");
        }

        private void FirePropertyChanged(string id)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(id));
            }
        }

        #endregion
    }
}