﻿using System;
using Dapfor.Wpf.Grid.Demo.Internal;

namespace Dapfor.Wpf.Grid.Demo.Examples.DataBinding.DeclarativeHierarchicalBinding
{
    /// <summary>
    /// Interaction logic for DeclarativeHierarchicalBindingDemo.xaml
    /// </summary>
    [Example("Data binding", "Declarative hierarchical binding", "Description_DeclarativeHierarchicalBindingDemo")]
    public partial class DeclarativeHierarchicalBindingDemo : IDisposable
    {
        private readonly Customers _customers;
        private readonly Random _r = new Random();

        public DeclarativeHierarchicalBindingDemo()
        {
            InitializeComponent();
          
            _customers = (Customers)FindResource("customers");
            _customers.Populate();


            hierarchicalGrid.Rows[1].Expanded = true;
        }

        public void Dispose()
        {
            _customers.Clear();
        }

        private void btnAddCustomer_Click(object sender, System.Windows.RoutedEventArgs e)
        {
            _customers.Add(new Customer("customer #" + (_customers.Count + 1), "Company #" + _r.Next(1, 20), "000-00-0000"));
        }

        private void btnRemoveCustomer_Click(object sender, System.Windows.RoutedEventArgs e)
        {
            if (_customers.Count > 0)
            {
                _customers.RemoveAt(_r.Next(0, _customers.Count));
            }
        }

        private void btnAddOrder_Click(object sender, System.Windows.RoutedEventArgs e)
        {
            foreach (Customer customer in _customers)
            {
                customer.Orders.Add(new Order("Order #" + (customer.Orders.Count + 1), "Product #" + _r.Next(1, 20), _r.Next(1, 20), _r.Next(100, 600) + _r.NextDouble()));
            }
        }

        private void btnRemoveOrders_Click(object sender, System.Windows.RoutedEventArgs e)
        {
            foreach (Customer customer in _customers)
            {
                if (customer.Orders.Count > 0)
                {
                    customer.Orders.RemoveAt(_r.Next(0, customer.Orders.Count));
                }
            }
        }
    }
}