﻿using System;
using System.IO;
using Dapfor.Wpf.Controls;
using Dapfor.Wpf.Grid.Demo.Internal;

namespace Dapfor.Wpf.Grid.Demo.Examples.Miscellaneous.FileExplorer
{
    /// <summary>
    /// Interaction logic for FileExplorerDemo.xaml
    /// </summary>
    [Example("Miscellaneous", "File explorer", "Description_FileExplorerDemo")]
    public partial class FileExplorerDemo
    {
        public FileExplorerDemo()
        {
            InitializeComponent();

            // Get all logical drives
            string[] drives = Environment.GetLogicalDrives();

            foreach (string strDrive in drives)
            {
                Row row = grid.Rows.Add(new DriveObject(strDrive));

                //Expand the drive C:
                if (string.Compare("c:\\", strDrive, true) == 0)
                {
                    row.Expanded = true;
                }
            }
        }


        private void grid_RowExpansionChanged(object sender, GridControlRowEventArgs e)
        {
            //When the row is opened, we can add files and directories as subitems of this row
            IExplorable dir = e.Row != null ? e.Row.DataObject as IExplorable : null;
            if (dir != null && e.Row.Children.Count == 0)
            {
                DirectoryInfo di = new DirectoryInfo(dir.FullName);
                if (di.Exists)
                {
                    try
                    {
                        foreach (DirectoryInfo directoryInfo in di.GetDirectories("*", SearchOption.TopDirectoryOnly))
                        {
                            //Add a new subfolder
                            e.Row.Add(new DirectoryObject(directoryInfo.Name, dir));
                        }

                        foreach (FileInfo fileInfo in di.GetFiles("*", SearchOption.TopDirectoryOnly))
                        {
                            //Add a file
                            e.Row.Add(new FileObject(fileInfo.Name, fileInfo.CreationTime, fileInfo.Length, fileInfo.Attributes, dir));
                        }
                    }
                    catch
                    {
                        //Access is denied
                    }
                }
            }
        }

        private void grid_ExpansionButtonState(object sender, GridControlExpansionButtonStateEventArgs e)
        {
            //When a directory is not opened yet, we can display an expansion icon (+) if it contains some files or subdirectories
            if(e.State == ExpansionButtonState.Hidden)
            {
                IExplorable dir = (IExplorable)e.Row.DataObject;
                if(dir.Expandable)
                {
                    e.State = e.Row.Expanded ? ExpansionButtonState.Collapsed : ExpansionButtonState.Expanded;
                }
            }
        }
    }
}