﻿using System;
using System.Windows;
using System.Windows.Media;
using Dapfor.Wpf.Controls;
using Dapfor.Wpf.Grid.Demo.Internal;

namespace Dapfor.Wpf.Grid.Demo.Examples.WhyUs.DynamicSorting
{
    /// <summary>
    /// Interaction logic for DynamicSortingDemo.xaml
    /// </summary>
    [Example("Why us?", "Dynamic sorting", "Description_WhyUsDynamicSorting")]
    public partial class DynamicSortingDemo
    {
        static readonly Random Random = new Random();
        readonly ShareCollection _shares = new ShareCollection();
        const int ShareIndex = 10;

        public DynamicSortingDemo()
        {
            InitializeComponent();

            grid.ItemsSource = _shares;

            grid.Headers[0]["Change"].SortDirection = SortDirection.Ascending;
            grid.DataObjects.FindFirstRow(_shares[ShareIndex]).Selected = true;

            grid.RowUpdated += (sender, e) =>
            {
                if (e.DataField.Id == "Last")
                {
                    Brush b = (double) e.Row["Change"].Value > 0 ? Brushes.Green : Brushes.DarkRed;
                    e.Row["Last"].Blink(TimeSpan.FromSeconds(1), b);
                    e.Row["Change"].Blink(TimeSpan.FromSeconds(1), b);
                }
            };
        }

        private void button1_Click(object sender, System.Windows.RoutedEventArgs e)
        {

            Share share = _shares[ShareIndex];
            
            double delta = share.Last * (1f / Random.Next(30, 500));
            delta = Random.Next() % 2 == 0 ? delta : -delta;
            share.Last = share.Open + delta;

            grid.DataObjects.FindFirstRow(_shares[ShareIndex]).EnsureVisible();
        }
    }
}
