﻿using System.Windows;
using System.Windows.Controls.Primitives;

namespace Dapfor.Wpf.Grid.Demo.GenericControls
{
    /// <summary>
    ///     Interaction logic for RatingControl.xaml
    /// </summary>
    public partial class RatingControl
    {
        private const int MaxValue = 5;

        public RatingControl()
        {
            InitializeComponent();
        }


        private void RatingButtonClickEventHandler(object sender, RoutedEventArgs e)
        {
            var button = sender as ToggleButton;
            if (button != null)
            {
                var newRating = int.Parse(button.Tag.ToString());
                RatingValue = newRating;
                e.Handled = true;
            }
        }

        #region RatingValue

        public static readonly DependencyProperty RatingValueProperty = DependencyProperty.Register("RatingValue", typeof (int), typeof (RatingControl), new FrameworkPropertyMetadata(0, FrameworkPropertyMetadataOptions.BindsTwoWayByDefault));

        public int RatingValue
        {
            get { return (int) GetValue(RatingValueProperty); }
            set
            {
                if (value < 0)
                {
                    SetValue(RatingValueProperty, 0);
                }
                else if (value > MaxValue)
                {
                    SetValue(RatingValueProperty, MaxValue);
                }
                else
                {
                    SetValue(RatingValueProperty, value);
                }
                RaiseRatingChangedEvent();
            }
        }

        #endregion


        #region Rating event

        public static readonly RoutedEvent RatingChangedEvent = EventManager.RegisterRoutedEvent("RatingChanged", RoutingStrategy.Bubble, typeof(RoutedEventHandler), typeof(RatingControl));

        public event RoutedEventHandler RatingChanged
        {
            add { AddHandler(RatingChangedEvent, value); }
            remove { RemoveHandler(RatingChangedEvent, value); }
        }

        protected virtual void RaiseRatingChangedEvent()
        {
            RoutedEventArgs args = new RoutedEventArgs(RatingChangedEvent);
            RaiseEvent(args);
        }

        #endregion

    }
}