﻿using System;
using System.ComponentModel;
using System.Reflection;
using System.Windows.Controls;
using Dapfor.Wpf.Grid.Demo.Properties;

namespace Dapfor.Wpf.Grid.Demo.Internal
{
    public class Example : INotifyPropertyChanged
    {
        private readonly string _name;
        private readonly string _description;
        private bool _isSelected;
        
        private readonly ConstructorInfo _constructor;

        public Example(string name, string description, Type exampleType)
        {
            _name = name;
            _description = description;
        
            _constructor = exampleType.GetConstructor(Type.EmptyTypes);
        }

        public string Name
        {
            get { return _name; }
        }

        public string Description
        {
            get
            {
                string result = Resources.ResourceManager.GetString(_description, Resources.Culture);
                if (string.IsNullOrEmpty(result) && !string.IsNullOrEmpty(_description))
                {
                    result = string.Format("[{0}]", _description);
                }

                return result;
            }
        }

        public Control CreateControl()
        {
            if(_constructor != null)
            {
                return (Control) _constructor.Invoke(Type.EmptyTypes);
            }
            return null;
        }

        public bool IsSelected
        {
            get
            {
                return _isSelected;
            }

            set
            {
                _isSelected = value;
                if (PropertyChanged != null)
                {
                    PropertyChanged(this, new PropertyChangedEventArgs("IsSelected"));
                }
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;
    }
}
