﻿using System;

namespace Dapfor.Wpf.Grid.Demo.Internal
{
    /// <summary>
    /// Marks the underlying wpf control as an example
    /// </summary>
    [AttributeUsage(AttributeTargets.Class, AllowMultiple = false, Inherited = false)]
    public sealed class ExampleAttribute : Attribute
    {
        #region Fields

        private readonly string _group;
        private readonly string _name;
        private readonly string _description;
        


        #endregion

        #region Constructor

        /// <summary>
        /// Initializes a new instance of the <see cref="ExampleAttribute"/> class.
        /// </summary>
        /// <param name="group">Example group.</param>
        /// <param name="name">Example name.</param>
        /// <param name="description">Example description.</param>
        public ExampleAttribute(string group, string name, string description)
        {
            _name = name;
            _group = group;
            _description = description;
        }

        #endregion

        #region Public properties

        /// <summary>
        /// Gets the name.
        /// </summary>
        /// <value>The name.</value>
        public string Name
        {
            get { return _name; }
        }

        /// <summary>
        /// Gets the group.
        /// </summary>
        /// <value>The group.</value>
        public string Group
        {
            get { return _group; }
        }

        /// <summary>
        /// Gets the description
        /// </summary>
        public string Description
        {
            get { return _description; }
        }

        #endregion
    }
}
